PodEnum

Trait PodEnum 

pub trait PodEnum: Pod {
    type Repr: Pod;
}
A trait marking this type as a plain-old-data enum

This is intended to be implemented by the pod_enum attribute macro, not to be implemented on its own.

Required Associated Types

type Repr: Pod

The type used for the internal representation

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors